@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 from dateutil.parser import isoparse
 
-from ..core.domain import BaseDomain, DomainIdentityMixin
+from ..core import BaseDomain, DomainIdentityMixin
 
 
 class Iso(BaseDomain, DomainIdentityMixin):
@@ -24,12 +26,12 @@ class Iso(BaseDomain, DomainIdentityMixin):
 
     def __init__(
         self,
-        id=None,
-        name=None,
-        type=None,
-        architecture=None,
-        description=None,
-        deprecated=None,
+        id: int | None = None,
+        name: str | None = None,
+        type: str | None = None,
+        architecture: str | None = None,
+        description: str | None = None,
+        deprecated: str | None = None,
     ):
         self.id = id
         self.name = name
