@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import pytest
 
 
@@ -12,12 +14,14 @@ def response_simple_server():
             "public_net": {
                 "ipv4": {
                     "ip": "1.2.3.4",
+                    "id": 1,
                     "blocked": False,
                     "dns_ptr": "server01.example.com",
                 },
                 "ipv6": {
                     "ip": "2001:db8::/64",
                     "blocked": False,
+                    "id": 2,
                     "dns_ptr": [{"ip": "2001:db8::1", "dns_ptr": "server.example.com"}],
                 },
                 "floating_ips": [478],
@@ -119,11 +123,13 @@ def response_create_simple_server():
                 "ipv4": {
                     "ip": "1.2.3.4",
                     "blocked": False,
+                    "id": 1,
                     "dns_ptr": "server01.example.com",
                 },
                 "ipv6": {
                     "ip": "2001:db8::/64",
                     "blocked": False,
+                    "id": 2,
                     "dns_ptr": [{"ip": "2001:db8::1", "dns_ptr": "server.example.com"}],
                 },
                 "floating_ips": [],
@@ -190,9 +196,7 @@ def response_create_simple_server():
                 "deprecated": "2018-02-28T00:00:00+00:00",
                 "labels": {},
             },
-            "iso": {
-                "id": 4711,
-            },
+            "iso": {"id": 4711},
             "rescue_enabled": False,
             "locked": False,
             "backup_window": "22-02",
@@ -241,11 +245,13 @@ def response_update_server():
                 "ipv4": {
                     "ip": "1.2.3.4",
                     "blocked": False,
+                    "id": 1,
                     "dns_ptr": "server01.example.com",
                 },
                 "ipv6": {
                     "ip": "2001:db8::/64",
                     "blocked": False,
+                    "id": 2,
                     "dns_ptr": [{"ip": "2001:db8::1", "dns_ptr": "server.example.com"}],
                 },
                 "floating_ips": [478],
@@ -345,11 +351,13 @@ def response_simple_servers():
                     "ipv4": {
                         "ip": "1.2.3.4",
                         "blocked": False,
+                        "id": 2,
                         "dns_ptr": "server01.example.com",
                     },
                     "ipv6": {
                         "ip": "2001:db8::/64",
                         "blocked": False,
+                        "id": 1,
                         "dns_ptr": [
                             {"ip": "2001:db8::1", "dns_ptr": "server.example.com"}
                         ],
@@ -445,11 +453,13 @@ def response_simple_servers():
                     "ipv4": {
                         "ip": "1.2.3.4",
                         "blocked": False,
+                        "id": 3,
                         "dns_ptr": "server01.example.com",
                     },
                     "ipv6": {
                         "ip": "2001:db8::/64",
                         "blocked": False,
+                        "id": 4,
                         "dns_ptr": [
                             {"ip": "2001:db8::1", "dns_ptr": "server.example.com"}
                         ],
@@ -554,11 +564,13 @@ def response_full_server():
                 "ipv4": {
                     "ip": "1.2.3.4",
                     "blocked": False,
+                    "id": 1,
                     "dns_ptr": "server01.example.com",
                 },
                 "ipv6": {
                     "ip": "2001:db8::/64",
                     "blocked": False,
+                    "id": 2,
                     "dns_ptr": [{"ip": "2001:db8::1", "dns_ptr": "server.example.com"}],
                 },
                 "floating_ips": [478],
@@ -627,6 +639,14 @@ def response_full_server():
                 "type": "public",
                 "deprecated": "2018-02-28T00:00:00+00:00",
             },
+            "placement_group": {
+                "created": "2019-01-08T12:10:00+00:00",
+                "id": 897,
+                "labels": {"key": "value"},
+                "name": "my Placement Group",
+                "servers": [4711, 4712],
+                "type": "spread",
+            },
             "rescue_enabled": False,
             "locked": False,
             "backup_window": "22-02",
@@ -831,3 +851,35 @@ def response_remove_firewall():
             "error": {"code": "action_failed", "message": "Action failed"},
         }
     }
+
+
+@pytest.fixture()
+def response_add_to_placement_group():
+    return {
+        "action": {
+            "command": "add_to_placement_group",
+            "error": {"code": "action_failed", "message": "Action failed"},
+            "finished": None,
+            "id": 13,
+            "progress": 0,
+            "resources": [{"id": 42, "type": "server"}],
+            "started": "2016-01-30T23:50:00+00:00",
+            "status": "running",
+        }
+    }
+
+
+@pytest.fixture()
+def response_remove_from_placement_group():
+    return {
+        "action": {
+            "command": "remove_from_placement_group",
+            "error": {"code": "action_failed", "message": "Action failed"},
+            "finished": "2016-01-30T23:56:00+00:00",
+            "id": 13,
+            "progress": 100,
+            "resources": [{"id": 42, "type": "server"}],
+            "started": "2016-01-30T23:55:00+00:00",
+            "status": "success",
+        }
+    }
